@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright 2021 KylinSoft Co., Ltd.
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,9 +12,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+
 #ifndef DEVICE_H
 #define DEVICE_H
 
@@ -29,13 +29,10 @@ struct DEV
     QString Type;
     QString PowerSupply;
     QString Online;
-    QString Vendor;
     QString Model;
-    QString Refresh;
     QString Energy;
     QString EnergyEmpty;
     QString EnergyFull;
-    QString EnergyFullDesign;
     QString EnergyRate;
     bool IsPresent;
     QString IsRechargeable;
@@ -45,19 +42,9 @@ struct DEV
     qlonglong TimeToFull;
     QString Voltage;
     double Capacity;
-    QString update_time;
-    QString serial;
     QString Technology;
-    bool hasHistory;
-    bool hasStat;
     QString path;
 
-    bool autorange_x;
-    int start_x;
-    int stop_x;
-    bool autorange_y;
-    int start_y;
-    int stop_y;
 };
 
 class DEVICE : public QObject
