@@ -1,10 +1,10 @@
 /*
- * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright 2021 KylinSoft Co., Ltd.
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,9 +12,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
- *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
@@ -31,6 +31,7 @@
 #include <QWidgetAction>
 #include <QLabel>
 #include <QTimer>
+#include <QTime>
 #include <powerwindow.h>
 
 class MainWindow : public QMainWindow
@@ -47,7 +48,7 @@ private:
     QList<QDBusObjectPath> deviceNames;
     QGSettings * settings;
     QMenu *menu;
-
+    QDBusInterface *iface;
 private Q_SLOTS:
     void set_preference_func();
     void onSumChanged(QString str);
