@@ -4,194 +4,154 @@
 <context>
     <name>EngineDevice</name>
     <message>
-        <location filename="../enginedevice.cpp" line="214"/>
+        <location filename="../enginedevice.cpp" line="111"/>
         <source>yes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="214"/>
+        <location filename="../enginedevice.cpp" line="111"/>
         <source>no</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="249"/>
+        <location filename="../enginedevice.cpp" line="146"/>
         <source>Yes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="249"/>
+        <location filename="../enginedevice.cpp" line="146"/>
         <source>No</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="628"/>
+        <location filename="../enginedevice.cpp" line="524"/>
         <source>Unknown time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="634"/>
-        <location filename="../enginedevice.cpp" line="655"/>
+        <location filename="../enginedevice.cpp" line="530"/>
+        <location filename="../enginedevice.cpp" line="551"/>
         <source>minute</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="636"/>
-        <location filename="../enginedevice.cpp" line="657"/>
+        <location filename="../enginedevice.cpp" line="532"/>
+        <location filename="../enginedevice.cpp" line="553"/>
         <source>minutes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="647"/>
-        <location filename="../enginedevice.cpp" line="659"/>
+        <location filename="../enginedevice.cpp" line="543"/>
+        <location filename="../enginedevice.cpp" line="555"/>
         <source>hour</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="649"/>
-        <location filename="../enginedevice.cpp" line="661"/>
+        <location filename="../enginedevice.cpp" line="545"/>
+        <location filename="../enginedevice.cpp" line="557"/>
         <source>hours</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="715"/>
-        <location filename="../enginedevice.cpp" line="718"/>
-        <location filename="../enginedevice.cpp" line="1162"/>
-        <source>fully charged</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../enginedevice.cpp" line="717"/>
-        <location filename="../enginedevice.cpp" line="740"/>
-        <location filename="../enginedevice.cpp" line="1171"/>
-        <location filename="../enginedevice.cpp" line="1183"/>
-        <source>charging</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../enginedevice.cpp" line="810"/>
+        <location filename="../enginedevice.cpp" line="610"/>
         <source>Left %1h %2m (%3%)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="818"/>
+        <location filename="../enginedevice.cpp" line="623"/>
         <source>charging (%1%)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="1168"/>
-        <source>discharging(%1%)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../enginedevice.cpp" line="894"/>
+        <location filename="../enginedevice.cpp" line="699"/>
         <source>AC adapter</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="738"/>
-        <source>not charging</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../enginedevice.cpp" line="806"/>
+        <location filename="../enginedevice.cpp" line="604"/>
         <source>%1% available, charged</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="816"/>
+        <location filename="../enginedevice.cpp" line="612"/>
+        <source>%1% available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../enginedevice.cpp" line="621"/>
         <source>Left %1h %2m to full</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="824"/>
+        <location filename="../enginedevice.cpp" line="629"/>
         <source>%1 waiting to discharge (%2%)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="830"/>
+        <location filename="../enginedevice.cpp" line="635"/>
         <source>%1 waiting to charge (%2%)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="898"/>
+        <location filename="../enginedevice.cpp" line="703"/>
         <source>Laptop battery</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="902"/>
+        <location filename="../enginedevice.cpp" line="707"/>
         <source>UPS</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="906"/>
+        <location filename="../enginedevice.cpp" line="711"/>
         <source>Monitor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="910"/>
+        <location filename="../enginedevice.cpp" line="715"/>
         <source>Mouse</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="914"/>
+        <location filename="../enginedevice.cpp" line="719"/>
         <source>Keyboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="918"/>
+        <location filename="../enginedevice.cpp" line="723"/>
         <source>PDA</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="922"/>
+        <location filename="../enginedevice.cpp" line="727"/>
         <source>Cell phone</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="926"/>
+        <location filename="../enginedevice.cpp" line="731"/>
         <source>Media player</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="930"/>
+        <location filename="../enginedevice.cpp" line="735"/>
         <source>Tablet</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="934"/>
+        <location filename="../enginedevice.cpp" line="739"/>
         <source>Computer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="938"/>
+        <location filename="../enginedevice.cpp" line="743"/>
         <source>unrecognised</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../enginedevice.cpp" line="1186"/>
-        <source>discharging</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../enginedevice.cpp" line="1189"/>
-        <source>empty</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../enginedevice.cpp" line="1192"/>
-        <source>fully</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../enginedevice.cpp" line="1195"/>
-        <source>other</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>PowerTray</name>
     <message>
-        <location filename="../mainwindow.cpp" line="87"/>
+        <location filename="../powertray.cpp" line="111"/>
         <source>SetPower</source>
         <translation type="unfinished"></translation>
     </message>
@@ -208,82 +168,94 @@
 <context>
     <name>powerwindow</name>
     <message>
-        <location filename="../powerwindow.cpp" line="76"/>
+        <location filename="../powerwindow.cpp" line="134"/>
+        <location filename="../powerwindow.cpp" line="267"/>
         <source>Charging</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="239"/>
-        <source>Left %1h %2m</source>
+        <location filename="../powerwindow.cpp" line="262"/>
+        <source>Left %1h 
+ %2m</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="352"/>
-        <location filename="../powerwindow.cpp" line="371"/>
-        <location filename="../powerwindow.cpp" line="406"/>
-        <location filename="../powerwindow.cpp" line="426"/>
-        <location filename="../powerwindow.cpp" line="445"/>
-        <location filename="../powerwindow.cpp" line="464"/>
+        <location filename="../powerwindow.cpp" line="264"/>
+        <source>Discharging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerwindow.cpp" line="270"/>
+        <source>fully charged</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerwindow.cpp" line="298"/>
+        <location filename="../powerwindow.cpp" line="312"/>
+        <location filename="../powerwindow.cpp" line="326"/>
+        <location filename="../powerwindow.cpp" line="343"/>
+        <location filename="../powerwindow.cpp" line="357"/>
+        <location filename="../powerwindow.cpp" line="372"/>
         <source>Power Manager</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="355"/>
+        <location filename="../powerwindow.cpp" line="298"/>
         <source>charge notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="356"/>
+        <location filename="../powerwindow.cpp" line="299"/>
         <source>battery is charging</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="374"/>
+        <location filename="../powerwindow.cpp" line="312"/>
         <source>discharged notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="375"/>
+        <location filename="../powerwindow.cpp" line="313"/>
         <source>battery is discharging</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="410"/>
+        <location filename="../powerwindow.cpp" line="329"/>
         <source>fullly charged notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="411"/>
+        <location filename="../powerwindow.cpp" line="329"/>
         <source>battery is fullly charged</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="429"/>
+        <location filename="../powerwindow.cpp" line="343"/>
         <source>low battery notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="430"/>
+        <location filename="../powerwindow.cpp" line="344"/>
         <source>battery is low, please plug in power</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="448"/>
+        <location filename="../powerwindow.cpp" line="358"/>
         <source>critical battery notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="449"/>
+        <location filename="../powerwindow.cpp" line="358"/>
         <source>battery is critical low,please plug in!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="467"/>
+        <location filename="../powerwindow.cpp" line="372"/>
         <source>operation notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="468"/>
+        <location filename="../powerwindow.cpp" line="373"/>
         <source>performing low power operation</source>
         <translation type="unfinished"></translation>
     </message>
@@ -291,7 +263,7 @@
 <context>
     <name>settinglabel</name>
     <message>
-        <location filename="../powerwindow.cpp" line="812"/>
+        <location filename="../powerwindow.cpp" line="511"/>
         <source>PowerSet</source>
         <translation type="unfinished"></translation>
     </message>
