@@ -18,68 +18,64 @@
 <context>
     <name>EngineDevice</name>
     <message>
-        <location filename="../enginedevice.cpp" line="214"/>
+        <location filename="../enginedevice.cpp" line="111"/>
         <source>yes</source>
         <translation>是</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="214"/>
+        <location filename="../enginedevice.cpp" line="111"/>
         <source>no</source>
         <translation>不</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="249"/>
+        <location filename="../enginedevice.cpp" line="146"/>
         <source>Yes</source>
         <translation>是</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="249"/>
+        <location filename="../enginedevice.cpp" line="146"/>
         <source>No</source>
         <translation>不</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="628"/>
+        <location filename="../enginedevice.cpp" line="524"/>
         <source>Unknown time</source>
         <translation>未知</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="634"/>
-        <location filename="../enginedevice.cpp" line="655"/>
+        <location filename="../enginedevice.cpp" line="530"/>
+        <location filename="../enginedevice.cpp" line="551"/>
         <source>minute</source>
         <translation>分钟</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="636"/>
-        <location filename="../enginedevice.cpp" line="657"/>
+        <location filename="../enginedevice.cpp" line="532"/>
+        <location filename="../enginedevice.cpp" line="553"/>
         <source>minutes</source>
         <translation>分钟</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="647"/>
-        <location filename="../enginedevice.cpp" line="659"/>
+        <location filename="../enginedevice.cpp" line="543"/>
+        <location filename="../enginedevice.cpp" line="555"/>
         <source>hour</source>
         <translation>小时</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="649"/>
-        <location filename="../enginedevice.cpp" line="661"/>
+        <location filename="../enginedevice.cpp" line="545"/>
+        <location filename="../enginedevice.cpp" line="557"/>
         <source>hours</source>
         <translation>小时</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="715"/>
-        <location filename="../enginedevice.cpp" line="718"/>
-        <location filename="../enginedevice.cpp" line="1162"/>
         <source>fully charged</source>
-        <translation>已充满</translation>
+        <translation type="vanished">已充满</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="738"/>
         <source>not charging</source>
-        <translation>未充电</translation>
+        <translation type="vanished">未充电</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="806"/>
+        <location filename="../enginedevice.cpp" line="604"/>
         <source>%1% available, charged</source>
         <translation>%1%可用，已充满</translation>
     </message>
@@ -92,134 +88,129 @@
         <translation type="vanished">%1%可用，正在充电</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="824"/>
+        <location filename="../enginedevice.cpp" line="629"/>
         <source>%1 waiting to discharge (%2%)</source>
         <translation>%1 等待放电 (%2%)</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="830"/>
+        <location filename="../enginedevice.cpp" line="635"/>
         <source>%1 waiting to charge (%2%)</source>
         <translation>%1 等待充电 (%2%)</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="1168"/>
         <source>discharging(%1%)</source>
-        <translation>放电(%1%)</translation>
+        <translation type="vanished">放电(%1%)</translation>
     </message>
     <message>
         <source>charging(%1%)</source>
         <translation type="vanished">充电(%1%)</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="894"/>
+        <location filename="../enginedevice.cpp" line="699"/>
         <source>AC adapter</source>
         <translation>交流电源适配器</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="898"/>
+        <location filename="../enginedevice.cpp" line="703"/>
         <source>Laptop battery</source>
         <translation>笔记本电池</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="902"/>
+        <location filename="../enginedevice.cpp" line="707"/>
         <source>UPS</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="906"/>
+        <location filename="../enginedevice.cpp" line="711"/>
         <source>Monitor</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="910"/>
+        <location filename="../enginedevice.cpp" line="715"/>
         <source>Mouse</source>
         <translation>鼠标</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="914"/>
+        <location filename="../enginedevice.cpp" line="719"/>
         <source>Keyboard</source>
         <translation>键盘</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="918"/>
+        <location filename="../enginedevice.cpp" line="723"/>
         <source>PDA</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="922"/>
+        <location filename="../enginedevice.cpp" line="727"/>
         <source>Cell phone</source>
         <translation>手机</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="926"/>
+        <location filename="../enginedevice.cpp" line="731"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="930"/>
+        <location filename="../enginedevice.cpp" line="735"/>
         <source>Tablet</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="934"/>
+        <location filename="../enginedevice.cpp" line="739"/>
         <source>Computer</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="938"/>
+        <location filename="../enginedevice.cpp" line="743"/>
         <source>unrecognised</source>
         <translation>未识别</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="717"/>
-        <location filename="../enginedevice.cpp" line="740"/>
-        <location filename="../enginedevice.cpp" line="1171"/>
-        <location filename="../enginedevice.cpp" line="1183"/>
         <source>charging</source>
-        <translation>正在充电</translation>
+        <translation type="vanished">正在充电</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="810"/>
+        <location filename="../enginedevice.cpp" line="610"/>
         <source>Left %1h %2m (%3%)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="816"/>
+        <location filename="../enginedevice.cpp" line="612"/>
+        <source>%1% available</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../enginedevice.cpp" line="621"/>
         <source>Left %1h %2m to full</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="818"/>
+        <location filename="../enginedevice.cpp" line="623"/>
         <source>charging (%1%)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="1186"/>
         <source>discharging</source>
-        <translation>放电</translation>
+        <translation type="vanished">放电</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="1189"/>
         <source>empty</source>
-        <translation>电量空</translation>
+        <translation type="vanished">电量空</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="1192"/>
         <source>fully</source>
-        <translation>电量满</translation>
+        <translation type="vanished">电量满</translation>
     </message>
     <message>
-        <location filename="../enginedevice.cpp" line="1195"/>
         <source>other</source>
-        <translation>其他</translation>
+        <translation type="vanished">其他</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="87"/>
         <source>SetPower</source>
-        <translation>设置电源和睡眠</translation>
+        <translation type="vanished">设置电源和睡眠</translation>
     </message>
     <message>
         <source>ShowPercentage</source>
@@ -299,6 +290,14 @@
         <translation type="vanished">亮度</translation>
     </message>
 </context>
+<context>
+    <name>PowerTray</name>
+    <message>
+        <location filename="../powertray.cpp" line="111"/>
+        <source>SetPower</source>
+        <translation type="unfinished">设置电源和睡眠</translation>
+    </message>
+</context>
 <context>
     <name>S:</name>
     <message>
@@ -311,86 +310,98 @@
 <context>
     <name>powerwindow</name>
     <message>
-        <location filename="../powerwindow.cpp" line="76"/>
+        <location filename="../powerwindow.cpp" line="134"/>
+        <location filename="../powerwindow.cpp" line="267"/>
         <source>Charging</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="239"/>
-        <source>Left %1h %2m</source>
+        <location filename="../powerwindow.cpp" line="262"/>
+        <source>Left %1h 
+ %2m</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../powerwindow.cpp" line="264"/>
+        <source>Discharging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../powerwindow.cpp" line="270"/>
+        <source>fully charged</source>
+        <translation type="unfinished">已充满</translation>
+    </message>
     <message>
         <source>PowerManagement</source>
         <translation type="obsolete">电源管理</translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="352"/>
-        <location filename="../powerwindow.cpp" line="371"/>
-        <location filename="../powerwindow.cpp" line="406"/>
-        <location filename="../powerwindow.cpp" line="426"/>
-        <location filename="../powerwindow.cpp" line="445"/>
-        <location filename="../powerwindow.cpp" line="464"/>
+        <location filename="../powerwindow.cpp" line="298"/>
+        <location filename="../powerwindow.cpp" line="312"/>
+        <location filename="../powerwindow.cpp" line="326"/>
+        <location filename="../powerwindow.cpp" line="343"/>
+        <location filename="../powerwindow.cpp" line="357"/>
+        <location filename="../powerwindow.cpp" line="372"/>
         <source>Power Manager</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="355"/>
+        <location filename="../powerwindow.cpp" line="298"/>
         <source>charge notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="356"/>
+        <location filename="../powerwindow.cpp" line="299"/>
         <source>battery is charging</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="374"/>
+        <location filename="../powerwindow.cpp" line="312"/>
         <source>discharged notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="375"/>
+        <location filename="../powerwindow.cpp" line="313"/>
         <source>battery is discharging</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="410"/>
+        <location filename="../powerwindow.cpp" line="329"/>
         <source>fullly charged notification</source>
         <translation type="unfinished">电池充满</translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="411"/>
+        <location filename="../powerwindow.cpp" line="329"/>
         <source>battery is fullly charged</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="429"/>
+        <location filename="../powerwindow.cpp" line="343"/>
         <source>low battery notification</source>
         <translation type="unfinished">电量低</translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="430"/>
+        <location filename="../powerwindow.cpp" line="344"/>
         <source>battery is low, please plug in power</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="448"/>
+        <location filename="../powerwindow.cpp" line="358"/>
         <source>critical battery notification</source>
         <translation type="unfinished">电量很低</translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="449"/>
+        <location filename="../powerwindow.cpp" line="358"/>
         <source>battery is critical low,please plug in!</source>
         <translation type="unfinished">电量很低，请充电</translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="467"/>
+        <location filename="../powerwindow.cpp" line="372"/>
         <source>operation notification</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../powerwindow.cpp" line="468"/>
+        <location filename="../powerwindow.cpp" line="373"/>
         <source>performing low power operation</source>
         <translation type="unfinished"></translation>
     </message>
@@ -398,7 +409,7 @@
 <context>
     <name>settinglabel</name>
     <message>
-        <location filename="../powerwindow.cpp" line="812"/>
+        <location filename="../powerwindow.cpp" line="511"/>
         <source>PowerSet</source>
         <translation type="unfinished"></translation>
     </message>
